/* This file is only used when ftw.theming and ftw.mobile is installed. */

#ftw-mobile-menu-buttons #subsitelanguage-mobile-button > a {
  @include auto-text-color($color-mobile-button);
  @include no-link();
  background-color: $color-mobile-button;
  width: $size-mobile-button;
  line-height: $size-mobile-button;
  font-size: $font-size-mobile-button;
  text-align: center;
  text-transform: uppercase;
  &:before {
    display: none;
  }
}

#portal-languageselector-wrapper #portal-languageselector{
  display: none;

  @include screen-medium {
    display: block;
  }
}
