#banner-image {
  position: relative;
  clear: both;
}

#portal-languageselector .actionMenuHeader a:after {
  content: " ▼";
}
#portal-languageselector .actionMenuContent {
  background: #E3E3E3;
  right: 0;
}
#portal-languageselector .actionMenuContent a {
  padding: 0.25em 0.5em;
}
#portal-languageselector .actionMenuContent a:hover {
  background: #205C90;
  color: #FFFFFF;
}
